@@ -180,7 +180,7 @@ class Samples(Sampling):
             xs: A 1D array indicating the roots, whose length is 2*num_m+1.
             success: A 1D array indicating the convergence information for xs.
         """
-        if self.clad.model == "pec":
+        if self.clad.label == "PEC":
             xs = self.beta2_pec(w, n)
             success = np.ones_like(xs, dtype=bool)
             return xs, success
@@ -241,11 +241,11 @@ class Samples(Sampling):
             xs: A 1D array indicating the roots, whose length is 2*num_m+1.
             success: A 1D array indicating the convergence information for xs.
         """
-        if self.clad.model == "pec":
+        w_0 = 0.1
+        if self.clad.label == "PEC":
             xs = self.beta2_pec(self.ws[0], n)
             success = np.ones_like(xs, dtype=bool)
             return xs, success
-        w_0 = 0.1
         e1 = self.fill(w_0)
         e2_0 = -5.0e5 + self.clad(w_0).imag * 1j
         de2 = (self.clad(w_0) - e2_0) / 1000
